@@ -5,5 +5,5 @@ class utils:
 
     @staticmethod
     def get_server_time(client):
-        response = http.get(f'https://{client["domen"]}/method/Utils.getServerTime?access_token={client["token"]}')
+        response = http.get(f'https://{client["instance"]}/method/Utils.getServerTime?access_token={client["token"]}')
         return json.loads(response.text)['response']
\ No newline at end of file
